@@ -1,6 +1,6 @@
 package Sparrow;
 
-our $VERSION = '0.2.15';
+our $VERSION = '0.2.16';
 
 1;
 
@@ -1042,9 +1042,11 @@ For example:
     $ export SPARROW_ROOT=/opt/sparrow
 
 
-=head2 SPARROWI<NO>COLOR 
+=head2 SPARROW_NO_COLOR 
 
-Disable color output
+Disable color output.
+
+    $ export SPARROW_NO_COLOR=1
 
 
 =head1 Remote Tasks
